<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="text" indent="no" omit-xml-declaration="yes"/>
	<xsl:strip-space elements="*"/>

	<xsl:variable name="maxColumnLen">79</xsl:variable>
	<xsl:variable name="strNOTE"><!--XLATESTART-->Note<!--XLATESTOP--></xsl:variable>
	<xsl:variable name="strCAUTION"><!--XLATESTART-->CAUTION<!--XLATESTOP--></xsl:variable>
	<xsl:variable name="strTestMode"><!--XLATESTART-->Test modes supported<!--XLATESTOP--></xsl:variable>
	<xsl:variable name="strTestCapabilities"><!--XLATESTART-->Test capabilities supported<!--XLATESTOP--></xsl:variable>
	<xsl:variable name="strLimitation"><!--XLATESTART-->Limitation<!--XLATESTOP--></xsl:variable>
	<xsl:variable name="strLimitations"><!--XLATESTART-->Limitations<!--XLATESTOP--></xsl:variable>
	<xsl:variable name="strTestDeatils"><!--XLATESTART-->You can run the following tests on this device:<!--XLATESTOP--></xsl:variable>
	<xsl:variable name="strNoHelp"><!--XLATESTART-->Diagnostic help is not available because diagnostic tests are not supported for the selected device class.<!--XLATESTOP--></xsl:variable>
	<xsl:variable name="strComma"><!--XLATESTART-->,<!--XLATESTOP--></xsl:variable>
	<xsl:variable name="strColan"><!--XLATESTART-->:<!--XLATESTOP--></xsl:variable>

	<xsl:template match="help">
		<xsl:call-template name="NewLine"/>
		<xsl:choose>
			<xsl:when test="count(.//DiagnosticHelp) &gt; 0">
				<xsl:apply-templates select="DiagnosticHelp"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="NoHelp"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="DiagnosticHelp">
		<xsl:call-template name="NewLine"/>
		<xsl:apply-templates select="DeviceTestPairs"/>
		<xsl:apply-templates select="DeviceName"/>
		<xsl:apply-templates select="DeviceDescription"/>
		<xsl:apply-templates select="Section"/>
		<xsl:apply-templates select="DeviceNote"/>
		<xsl:call-template name="NewLine"/>
	</xsl:template>

	<xsl:template match="DeviceTestPairs">
		<xsl:apply-templates/>
		<xsl:call-template name="NewLine"/>
	</xsl:template>

	<xsl:template match="DeviceName">
		<xsl:call-template name="CLISubCommand">
			<xsl:with-param name="command"><xsl:apply-templates/></xsl:with-param>
			<xsl:with-param name="frontSpaceVar">yes</xsl:with-param>
		</xsl:call-template>
		<xsl:call-template name="NewLine"/>
		<xsl:call-template name="NewLine"/>
	</xsl:template>

	<xsl:template match="DeviceDescription">
		<xsl:apply-templates/>
		<xsl:call-template name="NewLine"/>
		<xsl:call-template name="NewLine"/>
	</xsl:template>
	
	<xsl:template match="Section">
		<xsl:value-of select="normalize-space($strTestDeatils)"/>
		<xsl:call-template name="NewLine"/>
		<xsl:apply-templates select="Test"/>
	</xsl:template>

	<xsl:template match="text()">
		<xsl:choose>
			<xsl:when test="contains(., '&#174;')">
				<xsl:call-template name="escapeChars">
					<xsl:with-param name="value" select="."/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="normalize-space(.)"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="escapeChars">
		<xsl:param name="value"/>
		<xsl:choose>
			<xsl:when test="contains($value, '&#174;')">
				<xsl:value-of select="normalize-space(substring-before($value, '&#174;'))"/><xsl:text>(R) </xsl:text>
				<xsl:call-template name="escapeChars">
					<xsl:with-param name="value" select="substring-after($value, '&#174;')"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="normalize-space($value)"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="Test">
		<xsl:call-template name="NewLine"/>
		<xsl:value-of select="normalize-space(./TestName)"/><xsl:text> : </xsl:text>
		<xsl:choose>
			<xsl:when test="./TestDescription/Param">
				<xsl:value-of select="normalize-space(./TestDescription/text())"/>
				<xsl:for-each select="./TestDescription/Param">
					<xsl:text> - </xsl:text>
					<xsl:apply-templates/>
				</xsl:for-each>
			</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates select="./TestDescription"/>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:call-template name="DisplayTestDetails">
			<xsl:with-param name="testHeader" select="$strTestMode"/>
			<xsl:with-param name="compareNode" select="./TestMode"/>
		</xsl:call-template>
		<xsl:call-template name="DisplayTestDetails">
			<xsl:with-param name="testHeader" select="$strTestCapabilities"/>
			<xsl:with-param name="compareNode" select="./TestCapabilities"/>
		</xsl:call-template>
		<xsl:apply-templates select="Limitation"/>
		<xsl:apply-templates select="Note"/>
		<xsl:call-template name="NewLine"/>
	</xsl:template>

	<xsl:template name="DisplayTestDetails">
		<xsl:param name="testHeader"/>
		<xsl:param name="compareNode"/>
		<xsl:if test="$compareNode/Param[@type='' or not(@type)]">
			<xsl:call-template name="NewLine"/>
			<xsl:call-template name="CLISubCommand">
				<xsl:with-param name="command"><xsl:value-of select="$testHeader"/></xsl:with-param>
				<xsl:with-param name="spaceVar">27</xsl:with-param>
			</xsl:call-template><xsl:value-of select="$strColan"/><xsl:text> </xsl:text>
			<!--<xsl:value-of select="normalize-space($testHeader)"/><xsl:text> </xsl:text>-->
			<xsl:for-each select="$compareNode/Param[@type='' or not(@type)]"><xsl:value-of select="normalize-space(.)"/><xsl:if test="position() != last()"><xsl:value-of select="$strComma"/><xsl:text> </xsl:text></xsl:if></xsl:for-each>
		</xsl:if>
	</xsl:template>
	
	<xsl:template match="Limitation">
		<xsl:if test="./Param != ''">
			<xsl:call-template name="NewLine"/>
			<xsl:call-template name="CLISubCommand">
				<xsl:with-param name="command"><xsl:value-of select="$strLimitation"/></xsl:with-param>
				<xsl:with-param name="spaceVar">12</xsl:with-param>
			</xsl:call-template><xsl:value-of select="$strColan"/><xsl:text> </xsl:text>
			<xsl:apply-templates select="./Param"/>
		</xsl:if>
	</xsl:template>
	
	<xsl:template match="Param | TestDescription">
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="a | img | br | hr">
		<!-- Don't do anything -->
	</xsl:template>

	<xsl:template match="font | b | i | u | p | pre">
		<xsl:apply-templates select="text()"/>
	</xsl:template>

	<xsl:template match="Note">
		<xsl:call-template name="NewLine"/>
		<xsl:call-template name="CLISubCommand">
			<xsl:with-param name="command"><xsl:value-of select="$strNOTE"/></xsl:with-param>
			<xsl:with-param name="spaceVar">8</xsl:with-param>
		</xsl:call-template><xsl:value-of select="$strColan"/><xsl:text> </xsl:text>
		<xsl:apply-templates/>
	</xsl:template>

	<xsl:template match="DeviceNote">
		<xsl:call-template name="NewLine"/>
		<xsl:call-template name="CLISubCommand">
			<xsl:with-param name="command"><xsl:value-of select="$strCAUTION"/></xsl:with-param>
			<xsl:with-param name="spaceVar">8</xsl:with-param>
		</xsl:call-template><xsl:value-of select="$strColan"/><xsl:text> </xsl:text>
		<xsl:apply-templates/>
		<xsl:call-template name="NewLine"/>
	</xsl:template>

	<xsl:template name="NoHelp">
		<xsl:call-template name="NewLine"/>
		<xsl:value-of select="normalize-space($strNoHelp)"/>
	</xsl:template>

	<xsl:template name="CLISubCommand">
		<xsl:param name="command"/>
		<xsl:param name="spaceVar"/>
		<xsl:param name="frontSpaceVar"/>
		<xsl:if test="$command != ''">
			<xsl:if test="$frontSpaceVar != ''">
				<xsl:call-template name="Listspaces">
					<xsl:with-param name="num">
						<xsl:value-of select="(floor($maxColumnLen div 2) - floor(string-length($command) div 2))"/>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:if>
			<xsl:value-of select="$command"/>
			<xsl:if test="$spaceVar != ''">
				<xsl:call-template name="Listspaces">
					<xsl:with-param name="num">
						<xsl:value-of select="($spaceVar) - string-length($command)"/>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:if>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="Listspaces">
		<xsl:param name="num"/>
		<xsl:text> </xsl:text>
		<xsl:if test="$num &gt; '0'">
			<xsl:call-template name="Listspaces">
				<xsl:with-param name="num">
					<xsl:value-of select="($num) - 1"/>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="NewLine">
		<xsl:text>
</xsl:text>
	</xsl:template>
	<xsl:template match="*"></xsl:template>	
</xsl:stylesheet>
