<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="text" indent="no" omit-xml-declaration="yes"/>
	<xsl:strip-space elements="*"/>
	<!-- Deciding Params-->
	<xsl:param name="outfmt">10</xsl:param>
	<xsl:param name="deviceclass"/>
	<xsl:param name="device-index"></xsl:param>
	<!-- Deciding Params-->
	<xsl:variable name="deviceClassNotFound">The device class requested is not present/enumerated.</xsl:variable>
	<xsl:variable name="deviceIndexNotFound">No matching device was found while querying diagnostic device(s).</xsl:variable>
	<xsl:variable name="someDeviceIndexNotFound">No matching device was found for the device index</xsl:variable>
	<xsl:variable name="spaceVar">19</xsl:variable>
	<xsl:variable name="maxColumnLen">79</xsl:variable>
	<xsl:variable name="modDevice-index" select="concat(',', $device-index, ',')"/>

	<xsl:template match="tree">
		<xsl:variable name="deviceCount" select="count(.//device)"/>
		<xsl:choose>
			<xsl:when test="$deviceCount &gt; 0">
				<xsl:choose>
					<xsl:when test="$outfmt=11">
						<xsl:apply-templates select="device" mode="table"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:apply-templates select="device" mode="list"/>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:if test="$device-index !=''">
					<xsl:choose>
						<xsl:when test="contains($device-index, ',')">
							<xsl:variable name="NoMatchedIndex">
								<xsl:call-template name="MatchIndices">
									<xsl:with-param name="totalCount" select="$deviceCount"/>
									<xsl:with-param name="tokenizedIndex" select="$device-index"/>
								</xsl:call-template>
							</xsl:variable>
							<xsl:variable name="partialDisplayed">
								<xsl:call-template name="SpecifyPartialDisplay">
									<xsl:with-param name="totalCount" select="$deviceCount"/>
									<xsl:with-param name="tokenizedIndex" select="$device-index"/>
								</xsl:call-template>
							</xsl:variable>
							<xsl:if test="$NoMatchedIndex !=''">
								<xsl:choose>
									<xsl:when test="contains($partialDisplayed, 'yes')">
										<xsl:call-template name="NewLine"/>
										<xsl:value-of select="$someDeviceIndexNotFound"/> - <xsl:value-of select="substring-after($NoMatchedIndex, ',')"/>
										<xsl:call-template name="NewLine"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:call-template name="NewLine"/>
										<xsl:value-of select="$deviceIndexNotFound"/>
										<xsl:call-template name="NewLine"/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:if>
						</xsl:when>
						<xsl:otherwise>
							<xsl:if test="$device-index &gt; $deviceCount">
								<xsl:call-template name="NewLine"/>
								<xsl:value-of select="$deviceIndexNotFound"/>
								<xsl:call-template name="NewLine"/>
							</xsl:if>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="NewLine"/>
				<xsl:value-of select="$deviceClassNotFound"/>
				<xsl:call-template name="NewLine"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="MatchIndices">
		<xsl:param name="totalCount"/>
		<xsl:param name="tokenizedIndex"/>
		<xsl:choose>
			<xsl:when test="contains($tokenizedIndex, ',')">
				<xsl:if test="substring-before($tokenizedIndex, ',') &gt; $totalCount">,<xsl:value-of select="substring-before($tokenizedIndex, ',')"/></xsl:if>
				<xsl:call-template name="MatchIndices">
					<xsl:with-param name="totalCount" select="$totalCount"/>
					<xsl:with-param name="tokenizedIndex" select="substring-after($tokenizedIndex, ',')"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="$tokenizedIndex &gt; $totalCount">,<xsl:value-of select="$tokenizedIndex"/></xsl:if>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="SpecifyPartialDisplay">
		<xsl:param name="totalCount"/>
		<xsl:param name="tokenizedIndex"/>
		<xsl:choose>
			<xsl:when test="contains($tokenizedIndex, ',')">
				<xsl:if test="substring-before($tokenizedIndex, ',') &lt;= $totalCount">yes,</xsl:if>
				<xsl:call-template name="SpecifyPartialDisplay">
					<xsl:with-param name="totalCount" select="$totalCount"/>
					<xsl:with-param name="tokenizedIndex" select="substring-after($tokenizedIndex, ',')"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="$tokenizedIndex &lt;= $totalCount">yes,</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="device" mode="list">
		<xsl:variable name="index"><xsl:number level="any"/></xsl:variable>
		<xsl:choose>
			<xsl:when test="$device-index !=''">
				<xsl:if test="contains($modDevice-index, concat(',', $index, ','))">
					<xsl:call-template name="NewLine"/>
					<xsl:call-template name="PopulateList">
						<xsl:with-param name="index" select="$index"/>
						<xsl:with-param name="displayDirectives" select="../DisplayDirective[$index]"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="NewLine"/>
				<xsl:call-template name="PopulateList">
					<xsl:with-param name="index" select="$index"/>
					<xsl:with-param name="displayDirectives" select="../DisplayDirective"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="device" mode="table">
		<xsl:variable name="index"><xsl:number level="any"/></xsl:variable>
		<xsl:choose>
			<xsl:when test="$device-index !=''">
				<xsl:if test="contains($modDevice-index, concat(',', $index, ','))">
					<xsl:call-template name="NewLine"/>
					<xsl:call-template name="PopulateTable">
						<xsl:with-param name="index" select="$index"/>
						<xsl:with-param name="displayDirectives" select="../DisplayDirective[$index]"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="NewLine"/>
				<xsl:call-template name="PopulateTable">
					<xsl:with-param name="index" select="$index"/>
					<xsl:with-param name="displayDirectives" select="../DisplayDirective"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="PopulateList">
		<xsl:param name="index"/>
		<xsl:param name="displayDirectives"/>
		<xsl:variable name="nodeContent" select="."/>
		<xsl:for-each select="$displayDirectives">
			<xsl:sort order="ascending" select="@order" data-type="number"/>
			<xsl:variable name="elemname" select="@elemname"/>
			<xsl:if test="$elemname='deviceindex' or $elemname='testindex' or $nodeContent/*[name()=$elemname]/text() !=''">
				<xsl:call-template name="PrintListValues">
					<xsl:with-param name="nodeContent" select="$nodeContent"/>
					<xsl:with-param name="elemname" select="$elemname"/>
					<xsl:with-param name="index" select="$index"/>
				</xsl:call-template>
				<xsl:call-template name="NewLine"/>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="PrintListValues">
		<xsl:param name="index"/>
		<xsl:param name="nodeContent"/>
		<xsl:param name="elemname"/>
		<xsl:call-template name="CLISubCommand">
			<xsl:with-param name="command">
				<xsl:value-of select="@dispname"/>
			</xsl:with-param>
		</xsl:call-template>:<xsl:text> </xsl:text>
		<xsl:choose>
			<xsl:when test="$elemname='deviceindex' or $elemname='testindex'"><xsl:value-of select="$index"/></xsl:when>
			<xsl:otherwise><xsl:choose><xsl:when test="$elemname='deviceLocation'"><xsl:variable name="devFullLocation" select="normalize-space($nodeContent/*[name()=$elemname]/text())"/><xsl:call-template name="GiveOnlyLocation"><xsl:with-param name="devFullLocation" select="$devFullLocation"/></xsl:call-template></xsl:when><xsl:otherwise><xsl:value-of select="normalize-space($nodeContent/*[name()=$elemname]/text())"/></xsl:otherwise></xsl:choose>				
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="GiveOnlyLocation">
		<xsl:param name="devFullLocation"/>
		<xsl:choose>
			<xsl:when test="contains($devFullLocation, '!')">
				<xsl:call-template name="GiveOnlyLocation">
					<xsl:with-param name="devFullLocation" select="substring-after($devFullLocation, '!')"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise><xsl:value-of select="$devFullLocation"/></xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="CLISubCommand">
		<xsl:param name="command"/>
		<xsl:if test="$command != ''">
			<xsl:value-of select="$command"/>
			<xsl:call-template name="Listspaces">
				<xsl:with-param name="num">
					<xsl:value-of select="($spaceVar) -  string-length($command)"/>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="PopulateTable">
		<xsl:param name="index"/>
		<xsl:param name="displayDirectives"/>
		<xsl:variable name="nodeContent" select="."/>
		<xsl:variable name="tmpattlen">
			<xsl:call-template name="MAX">
				<xsl:with-param name="list" select="$displayDirectives"/>
				<xsl:with-param name="type">display</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="tmpvallen">
			<xsl:call-template name="MAX">
				<xsl:with-param name="list" select="$displayDirectives"/>
				<xsl:with-param name="nodeContentVar" select="$nodeContent"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="maxatt">
			<xsl:choose>
				<xsl:when test="$tmpattlen &gt; '9'">
					<xsl:value-of select="$tmpattlen"/>
				</xsl:when>
				<xsl:otherwise>9</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="maxvalfirst">
			<xsl:choose>
				<xsl:when test="$tmpvallen &gt; '5'">
					<xsl:value-of select="$tmpvallen"/>
				</xsl:when>
				<xsl:otherwise>5</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="maxval">
			<xsl:choose>
				<xsl:when test="($maxColumnLen - ($maxatt + $maxvalfirst + 6) &gt; 0)">
					<xsl:value-of select="$maxvalfirst"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="($maxColumnLen - ($maxatt + 6))"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>		
		<xsl:variable name="maxlength">
			<xsl:value-of select="$maxatt + $maxval + 6"/>
		</xsl:variable>
	<!--	[tmpattlen=<xsl:value-of select="$tmpattlen"/>;tmpvallen=<xsl:value-of  select="$tmpvallen"/>;maxatt=<xsl:value-of select="$maxatt"/>;maxval=<xsl:value-of  select="$maxval"/>;maxlength=<xsl:value-of select="$maxlength"/>] -->
		<xsl:call-template name="Tablespaces">
			<xsl:with-param name="length" select="$maxlength"/>
			<xsl:with-param name="character" select="'-'"/>
		</xsl:call-template>
		<xsl:call-template name="NewLine"/>
		<xsl:text> ATTRIBUTE</xsl:text>
		<xsl:call-template name="Tablespaces">
			<xsl:with-param name="length" select="($maxatt - 9)"/>
			<xsl:with-param name="character" select="' '"/>
		</xsl:call-template>
		<xsl:text> | VALUE</xsl:text>
		<xsl:call-template name="Tablespaces">
			<xsl:with-param name="length" select="($maxval - 5)"/>
			<xsl:with-param name="character" select="' '"/>
		</xsl:call-template>
		<xsl:call-template name="endRow"/>
		<xsl:call-template name="NewLine"/>
		<xsl:call-template name="Tablespaces">
			<xsl:with-param name="length" select="$maxlength"/>
			<xsl:with-param name="character" select="'-'"/>
		</xsl:call-template>
		<xsl:call-template name="NewLine"/>
		<xsl:for-each select="$displayDirectives">
			<xsl:sort order="ascending" select="@order" data-type="number"/>
			<xsl:variable name="elemname" select="@elemname"/>
			<xsl:if test="$elemname='deviceindex' or $elemname='testindex' or $nodeContent/*[name()=$elemname]/text() !=''">
				<xsl:text> </xsl:text>
				<xsl:value-of select="@dispname"/>
				<xsl:call-template name="Tablespaces">
					<xsl:with-param name="length" select="($maxatt -  string-length(@dispname))"/>
					<xsl:with-param name="character" select="' '"/>
				</xsl:call-template>
				<xsl:text> | </xsl:text>
				<xsl:call-template name="PrintValue"><xsl:with-param name="nodeContentVar" select="$nodeContent"/><xsl:with-param name="elemname" select="$elemname"/><xsl:with-param name="maxlength" select="$maxlength"/><xsl:with-param name="maxatt" select="$maxatt"/><xsl:with-param name="maxval" select="$maxval"/><xsl:with-param name="index" select="$index"/></xsl:call-template><xsl:variable name="printvallen"><xsl:choose>	<xsl:when test="$elemname='deviceindex' or $elemname='testindex'"><xsl:value-of select="string-length($index)"/></xsl:when><xsl:otherwise><xsl:call-template name="MAX"><xsl:with-param name="list" select="."/><xsl:with-param name="nodeContentVar" select="$nodeContent"/></xsl:call-template></xsl:otherwise></xsl:choose></xsl:variable>
				<xsl:if test="$maxval &gt;= $printvallen">
					<xsl:call-template name="Tablespaces">
						<xsl:with-param name="length" select="($maxval -  $printvallen)"/>
						<xsl:with-param name="character" select="' '"/>
					</xsl:call-template>
					<xsl:call-template name="endRow"/>
				</xsl:if>
				<xsl:call-template name="NewLine"/>
				<xsl:call-template name="Tablespaces">
					<xsl:with-param name="length" select="$maxlength"/>
					<xsl:with-param name="character" select="'-'"/>
				</xsl:call-template>
				<xsl:call-template name="NewLine"/>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="PrintValue">
		<xsl:param name="nodeContentVar"/>
		<xsl:param name="elemname"/>
		<xsl:param name="maxlength"/>
		<xsl:param name="maxatt"/>
		<xsl:param name="maxval"/>
		<xsl:param name="index"/>
		<xsl:choose>
			<xsl:when test="$elemname='deviceindex' or $elemname='testindex'"><xsl:value-of select="$index"/></xsl:when>
			<xsl:otherwise>
				<xsl:variable name="StringValue"><xsl:choose><xsl:when test="$elemname='deviceLocation'"><xsl:variable name="devFullLocation" select="normalize-space($nodeContentVar/*[name()=$elemname]/text())"/><xsl:call-template name="GiveOnlyLocation"><xsl:with-param name="devFullLocation" select="$devFullLocation"/></xsl:call-template></xsl:when><xsl:otherwise><xsl:value-of select="normalize-space($nodeContentVar/*[name()=$elemname]/text())"/></xsl:otherwise></xsl:choose></xsl:variable>
				<xsl:variable name="StringValLength" select="string-length($StringValue)"/>
				<xsl:choose>
					<xsl:when test="($StringValLength &gt; $maxval)">
						<xsl:call-template name="BeautifyLengthyValue">
							<xsl:with-param name="StringValue" select="$StringValue"/>
							<xsl:with-param name="StringValLength" select="$StringValLength"/>
							<xsl:with-param name="maxatt" select="$maxatt"/>
							<xsl:with-param name="maxval" select="$maxval"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$StringValue"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="BeautifyLengthyValue">
		<xsl:param name="StringValue"/>
		<xsl:param name="StringValLength"/>
		<xsl:param name="maxatt"/>
		<xsl:param name="maxval"/>
		<xsl:param name="secondOnwards"/>
		<xsl:choose>
			<xsl:when test="($StringValLength &gt; $maxval)">
				<xsl:if test="$secondOnwards = 'yes'">
					<xsl:call-template name="Tablespaces">
						<xsl:with-param name="length" select="$maxatt + 1"/>
						<xsl:with-param name="character" select="' '"/>
					</xsl:call-template>
					<xsl:text> | </xsl:text>
				</xsl:if>
				<xsl:value-of select="substring($StringValue, 0, $maxval+1)"/>
				<xsl:call-template name="endRow"/>
				<xsl:call-template name="NewLine"/>
				<xsl:call-template name="BeautifyLengthyValue">
					<xsl:with-param name="StringValue" select="substring($StringValue, ($maxval+1))"/>
					<xsl:with-param name="StringValLength" select="string-length(substring($StringValue, ($maxval+1)))"/>
					<xsl:with-param name="maxatt" select="$maxatt"/>
					<xsl:with-param name="maxval" select="$maxval"/>
					<xsl:with-param name="secondOnwards" select="'yes'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="Tablespaces">
					<xsl:with-param name="length" select="$maxatt + 1"/>
					<xsl:with-param name="character" select="' '"/>
				</xsl:call-template>
				<xsl:text> | </xsl:text>
				<xsl:value-of select="$StringValue"/>
				<xsl:call-template name="Tablespaces">
					<xsl:with-param name="length" select="($maxColumnLen - (string-length($StringValue) + $maxatt + 6))"/>
					<xsl:with-param name="character" select="' '"/>
				</xsl:call-template>
				<xsl:call-template name="endRow"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="startRow">
		<xsl:text>| </xsl:text>
	</xsl:template>
	<xsl:template name="endRow">
		<xsl:text> |</xsl:text>
	</xsl:template>

	<xsl:template name="MAX">
		<xsl:param name="list"/>
		<xsl:param name="nodeContentVar"/>
		<xsl:param name="type"/>
		<xsl:choose>
			<xsl:when test="$list">
				<xsl:variable name="first">
					<xsl:choose>
						<xsl:when test="$type='display'">
							<xsl:value-of select="string-length(normalize-space($list[1]/@dispname))"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:for-each select="$list[1]">
								<xsl:sort order="ascending" select="@order" data-type="number"/>
								<xsl:call-template name="PrintLength">
									<xsl:with-param name="nodeContentVar" select="$nodeContentVar"/>
									<xsl:with-param name="elemname" select="@elemname"/>
								</xsl:call-template>
							</xsl:for-each>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				<xsl:variable name="rest">
					<xsl:call-template name="MAX">
						<xsl:with-param name="list" select="$list[position()!=1]"/>
						<xsl:with-param name="nodeContentVar" select="$nodeContentVar"/>
						<xsl:with-param name="type" select="$type"/>
					</xsl:call-template>
				</xsl:variable>
				<xsl:choose>
					<!--The following translate stuff removes spurious  comma inserted when in French or German Locale under Linux 7.2  -->
					<xsl:when test="normalize-space(translate($first,',','  ')) &gt; normalize-space(translate($rest,',',' ')) ">
						<xsl:value-of select="normalize-space(translate($first,',',' '))"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$rest"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>0</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="PrintLength">
		<xsl:param name="nodeContentVar"/>
		<xsl:param name="elemname"/>
		<xsl:choose><xsl:when test="$elemname='deviceLocation'"><xsl:variable name="devFullLocation" select="normalize-space($nodeContentVar/*[name()=$elemname]/text())"/><xsl:variable name="strOnlyLocation"><xsl:call-template name="GiveOnlyLocation"><xsl:with-param name="devFullLocation" select="$devFullLocation"/></xsl:call-template></xsl:variable><xsl:value-of select="string-length($strOnlyLocation)"/></xsl:when><xsl:otherwise><xsl:value-of select="string-length(normalize-space($nodeContentVar/*[name()=$elemname]/text()))"/></xsl:otherwise></xsl:choose>
	</xsl:template>

	<xsl:template name="Listspaces">
		<xsl:param name="num"/>
		<xsl:text> </xsl:text>
		<xsl:if test="$num &gt; '0'">
			<xsl:call-template name="Listspaces">
				<xsl:with-param name="num">
					<xsl:value-of select="($num) - 1"/>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="Tablespaces">
		<xsl:param name="length"/>
		<xsl:param name="character"/>
		<xsl:if test="$length!=0">
			<xsl:value-of select="$character"/>
			<xsl:call-template name="Tablespaces">
				<!--The following translate stuff removes spurious comma  inserted when in French or German Locale under Linux 7.2  -->
				<xsl:with-param name="length"  select="normalize-space(translate($length,',',' '))-1"/>
				<xsl:with-param name="character" select="$character"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="NewLine">
		<xsl:text>
</xsl:text>
	</xsl:template>
	<xsl:template match="*"></xsl:template>	
</xsl:stylesheet>