<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="xml" indent="yes" omit-xml-declaration="yes"/>
	<xsl:strip-space elements="*"/>
	<!-- Deciding Params-->
	<xsl:param name="outfmt">12</xsl:param>
	<xsl:param name="deviceclass"/>
	<xsl:param name="device-index"></xsl:param>
	<xsl:param name="test-index"></xsl:param>
	<!-- Deciding Params-->
	<xsl:variable name="deviceClassNotFound">The device class requested is not present/enumerated.</xsl:variable>
	<xsl:variable name="deviceIndexNotFound">No matching device was found while querying diagnostic device(s).</xsl:variable>
	<xsl:variable name="someDeviceIndexNotFound">No matching device was found for the device index</xsl:variable>
	<xsl:variable name="testIndexNotFound">No matching test was found while querying diagnostic test(s).</xsl:variable>
	<xsl:variable name="someTestIndexNotFound">No matching test was found for the test index</xsl:variable>
	<xsl:variable name="modDevice-index" select="concat(',', $device-index, ',')"/>
	<xsl:variable name="modTest-index" select="concat(',', $test-index, ',')"/>

<!--
	<xsl:template match="tree">
		<xsl:variable name="deviceCount" select="count(.//device)"/>
		<xsl:choose>
			<xsl:when test="$deviceCount &gt; 0">
				<xsl:element name="tree">
					<xsl:apply-templates select="device" mode="xml"/>
				</xsl:element>
				<xsl:call-template name="NewLine"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="NewLine"/>
				<xsl:value-of select="$deviceClassNotFound"/>
				<xsl:call-template name="NewLine"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
-->
	<xsl:template match="tree">
		<xsl:variable name="deviceCount" select="count(.//device)"/>
		<xsl:choose>
			<xsl:when test="$deviceCount &gt; 0">
				<xsl:variable name="maxIndTests">
					<xsl:call-template name="MaxTests">
						<xsl:with-param name="list" select=".//device"/>
					</xsl:call-template>
				</xsl:variable>
				<xsl:variable name="deviceTestPairs">
					<xsl:call-template name="DevicesAndTests">
						<xsl:with-param name="list" select=".//device"/>
					</xsl:call-template>
				</xsl:variable>
				<!--
				<xsl:call-template name="NewLine"/>
				<xsl:element name="tree">
					<xsl:apply-templates select="device" mode="xml"/>
				</xsl:element>
				<xsl:call-template name="NewLine"/>
				-->
				<xsl:choose>
					<xsl:when test="($device-index !='') and ($test-index !='')">
						<xsl:variable name="MatchedIndices">
							<xsl:call-template name="MatchDeviceTestIndices">
								<xsl:with-param name="deviceTestPairs" select="$deviceTestPairs"/>
								<xsl:with-param name="index" select="$device-index"/>
							</xsl:call-template>
						</xsl:variable>
						
						<xsl:choose>
							<xsl:when test="contains($device-index, ',')">
								<xsl:variable name="NoMatchedIndex">
									<xsl:call-template name="MatchIndices">
										<xsl:with-param name="totalCount" select="$deviceCount"/>
										<xsl:with-param name="tokenizedIndex" select="$device-index"/>
									</xsl:call-template>
								</xsl:variable>
								<xsl:variable name="partialDisplayed">
									<xsl:call-template name="SpecifyPartialDisplay">
										<xsl:with-param name="totalCount" select="$deviceCount"/>
										<xsl:with-param name="tokenizedIndex" select="$device-index"/>
									</xsl:call-template>
								</xsl:variable>
								<xsl:choose>
									<xsl:when test="$NoMatchedIndex !=''">
										<xsl:choose>
											<xsl:when test="contains($partialDisplayed, 'yes')">
												<xsl:call-template name="NewLine"/>
												<xsl:element name="tree">
													<xsl:apply-templates select="device" mode="xml"/>
												</xsl:element>
												<xsl:call-template name="NewLine"/>
												<xsl:call-template name="NewLine"/>
												<xsl:value-of select="$someDeviceIndexNotFound"/> - <xsl:value-of select="substring-after($NoMatchedIndex, ',')"/>
												<xsl:call-template name="NewLine"/>
											</xsl:when>
											<xsl:otherwise>
												<xsl:call-template name="NewLine"/>
												<xsl:value-of select="$deviceIndexNotFound"/>
												<xsl:call-template name="NewLine"/>
											</xsl:otherwise>
										</xsl:choose>
									</xsl:when>
									<xsl:otherwise>
										<xsl:call-template name="NewLine"/>
										<xsl:element name="tree">
											<xsl:apply-templates select="device" mode="xml"/>
										</xsl:element>
										<xsl:call-template name="NewLine"/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:when>
							<xsl:otherwise>
								<xsl:choose>
									<xsl:when test="$device-index &gt; $deviceCount">
										<xsl:call-template name="NewLine"/>
										<xsl:value-of select="$deviceIndexNotFound"/>
										<xsl:call-template name="NewLine"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:call-template name="NewLine"/>
										<xsl:element name="tree">
											<xsl:apply-templates select="device" mode="xml"/>
										</xsl:element>
										<xsl:call-template name="NewLine"/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:otherwise>
						</xsl:choose>
						
						<xsl:variable name="tokenizedMatchedIndices"><xsl:value-of select="concat($MatchedIndices, ',')"/></xsl:variable>
						<xsl:choose>
							<xsl:when test="contains($MatchedIndices, ',')">
								<xsl:variable name="finalOutTest">
									<xsl:call-template name="CompareTokenStrs">
										<xsl:with-param name="tokenStrUser" select="$test-index"/>
										<xsl:with-param name="tokenStrTest" select="$tokenizedMatchedIndices"/>
									</xsl:call-template>
								</xsl:variable>
								<xsl:if test="$finalOutTest != ''">
									<xsl:call-template name="NewLine"/>
									<xsl:value-of select="$someTestIndexNotFound"/> - <xsl:choose><xsl:when test="starts-with($finalOutTest, ',')"><xsl:value-of select="substring-after($finalOutTest, ',')"/></xsl:when><xsl:otherwise><xsl:value-of select="$finalOutTest"/></xsl:otherwise></xsl:choose>
									<xsl:call-template name="NewLine"/>
								</xsl:if>
							</xsl:when>
							<xsl:otherwise>
								<xsl:call-template name="NewLine"/>
								<xsl:value-of select="$testIndexNotFound"/>
								<xsl:call-template name="NewLine"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>

					<xsl:when test="$device-index !=''">
						<xsl:choose>
							<xsl:when test="contains($device-index, ',')">
								<xsl:variable name="NoMatchedIndex">
									<xsl:call-template name="MatchIndices">
										<xsl:with-param name="totalCount" select="$deviceCount"/>
										<xsl:with-param name="tokenizedIndex" select="$device-index"/>
									</xsl:call-template>
								</xsl:variable>
								<xsl:variable name="partialDisplayed">
									<xsl:call-template name="SpecifyPartialDisplay">
										<xsl:with-param name="totalCount" select="$deviceCount"/>
										<xsl:with-param name="tokenizedIndex" select="$device-index"/>
									</xsl:call-template>
								</xsl:variable>
								<xsl:choose>
									<xsl:when test="$NoMatchedIndex !=''">
										<xsl:choose>
											<xsl:when test="contains($partialDisplayed, 'yes')">
												<xsl:call-template name="NewLine"/>
												<xsl:element name="tree">
													<xsl:apply-templates select="device" mode="xml"/>
												</xsl:element>
												<xsl:call-template name="NewLine"/>
												<xsl:call-template name="NewLine"/>
												<xsl:value-of select="$someDeviceIndexNotFound"/> - <xsl:value-of select="substring-after($NoMatchedIndex, ',')"/>
												<xsl:call-template name="NewLine"/>
											</xsl:when>
											<xsl:otherwise>
												<xsl:call-template name="NewLine"/>
												<xsl:value-of select="$deviceIndexNotFound"/>
												<xsl:call-template name="NewLine"/>
											</xsl:otherwise>
										</xsl:choose>
									</xsl:when>
									<xsl:otherwise>
										<xsl:call-template name="NewLine"/>
										<xsl:element name="tree">
											<xsl:apply-templates select="device" mode="xml"/>
										</xsl:element>
										<xsl:call-template name="NewLine"/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:when>
							<xsl:otherwise>
								<xsl:choose>
									<xsl:when test="$device-index &gt; $deviceCount">
										<xsl:call-template name="NewLine"/>
										<xsl:value-of select="$deviceIndexNotFound"/>
										<xsl:call-template name="NewLine"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:call-template name="NewLine"/>
										<xsl:element name="tree">
											<xsl:apply-templates select="device" mode="xml"/>
										</xsl:element>
										<xsl:call-template name="NewLine"/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					
					<xsl:when test="$test-index !=''">
						<xsl:choose>
							<xsl:when test="contains($test-index, ',')">
								<xsl:variable name="NoMatchedIndex">
									<xsl:call-template name="MatchIndices">
										<xsl:with-param name="totalCount" select="$maxIndTests"/>
										<xsl:with-param name="tokenizedIndex" select="$test-index"/>
									</xsl:call-template>
								</xsl:variable>
								<xsl:variable name="partialDisplayed">
									<xsl:call-template name="SpecifyPartialDisplay">
										<xsl:with-param name="totalCount" select="$maxIndTests"/>
										<xsl:with-param name="tokenizedIndex" select="$test-index"/>
									</xsl:call-template>
								</xsl:variable>
								<xsl:choose>
									<xsl:when test="$NoMatchedIndex !=''">
										<xsl:choose>
											<xsl:when test="contains($partialDisplayed, 'yes')">
												<xsl:call-template name="NewLine"/>
												<xsl:element name="tree">
													<xsl:apply-templates select="device" mode="xml"/>
												</xsl:element>
												<xsl:call-template name="NewLine"/>
												<xsl:call-template name="NewLine"/>
												<xsl:value-of select="$someTestIndexNotFound"/> - <xsl:value-of select="substring-after($NoMatchedIndex, ',')"/>
												<xsl:call-template name="NewLine"/>
											</xsl:when>
											<xsl:otherwise>
												<xsl:call-template name="NewLine"/>
												<xsl:element name="tree">
													<xsl:apply-templates select="device" mode="xml"/>
												</xsl:element>
												<xsl:call-template name="NewLine"/>
												<xsl:call-template name="NewLine"/>
												<xsl:value-of select="$testIndexNotFound"/>
												<xsl:call-template name="NewLine"/>
											</xsl:otherwise>
										</xsl:choose>
									</xsl:when>
									<xsl:otherwise>
										<xsl:call-template name="NewLine"/>
										<xsl:element name="tree">
											<xsl:apply-templates select="device" mode="xml"/>
										</xsl:element>
										<xsl:call-template name="NewLine"/>
									</xsl:otherwise>
								</xsl:choose>	
							</xsl:when>
							<xsl:otherwise>
								<xsl:choose>
									<xsl:when test="$test-index &gt; $maxIndTests">
										<xsl:call-template name="NewLine"/>
										<xsl:element name="tree">
											<xsl:apply-templates select="device" mode="xml"/>
										</xsl:element>
										<xsl:call-template name="NewLine"/>
										<xsl:call-template name="NewLine"/>
										<xsl:value-of select="$testIndexNotFound"/>
										<xsl:call-template name="NewLine"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:call-template name="NewLine"/>
										<xsl:element name="tree">
											<xsl:apply-templates select="device" mode="xml"/>
										</xsl:element>
										<xsl:call-template name="NewLine"/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="NewLine"/>
						<xsl:element name="tree">
							<xsl:apply-templates select="device" mode="xml"/>
						</xsl:element>
						<xsl:call-template name="NewLine"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="NewLine"/>
				<xsl:value-of select="$deviceClassNotFound"/>
				<xsl:call-template name="NewLine"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="CompareTokenStrs">
		<xsl:param name="tokenStrUser"/>
		<xsl:param name="tokenStrTest"/>
		<xsl:choose>
			<xsl:when test="contains($tokenStrUser, ',')">
				<xsl:if test="not(contains($tokenStrTest, concat(',', substring-before($tokenStrUser, ','), ',')))">,<xsl:value-of select="substring-before($tokenStrUser, ',')"/></xsl:if>
				<xsl:call-template name="CompareTokenStrs">
					<xsl:with-param name="tokenStrUser" select="substring-after($tokenStrUser, ',')"/>
					<xsl:with-param name="tokenStrTest" select="$tokenStrTest"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="not(contains($tokenStrTest, concat(',', $tokenStrUser, ',')))">,<xsl:value-of select="$tokenStrUser"/></xsl:if>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="DevicesAndTests">
		<xsl:param name="list"/>
		<xsl:for-each select="$list">;<xsl:value-of select="position()"/>,<xsl:value-of select="count(.//test)"/><xsl:if test="position() = last()">;</xsl:if></xsl:for-each>
	</xsl:template>

	<xsl:template name="MatchDeviceTestIndices">
		<xsl:param name="deviceTestPairs"/>
		<xsl:param name="index"/>
		<xsl:param name="temptest"/>
		<xsl:choose>
			<xsl:when test="contains($index, ',')">
				<xsl:variable name="indDevIndex" select="substring-before($index, ',')"/>
				<xsl:choose>
					<xsl:when test="contains($deviceTestPairs, concat(';', $indDevIndex, ','))">
						<xsl:variable name="corresMaxTest" select="substring-before(substring-after($deviceTestPairs, concat(';', $indDevIndex, ',')), ';')"/>
						<xsl:call-template name="TokenizedMatch">
							<xsl:with-param name="totalCount" select="$corresMaxTest"/>
							<xsl:with-param name="tokenizedIndex" select="$test-index"/>
						</xsl:call-template>
					</xsl:when>
				</xsl:choose>
				<xsl:call-template name="MatchDeviceTestIndices">
					<xsl:with-param name="deviceTestPairs" select="$deviceTestPairs"/>
					<xsl:with-param name="index" select="substring-after($index, ',')"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="contains($deviceTestPairs, concat(';', $index, ','))">
						<xsl:variable name="corresMaxTest" select="substring-before(substring-after($deviceTestPairs, concat(';', $index, ',')), ';')"/>
							<xsl:call-template name="TokenizedMatch">
								<xsl:with-param name="totalCount" select="$corresMaxTest"/>
								<xsl:with-param name="tokenizedIndex" select="$test-index"/>
							</xsl:call-template>
					</xsl:when>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="MaxTests">
		<xsl:param name="list"/>
		<xsl:choose>
			<xsl:when test="$list">
				<xsl:variable name="first">
					<xsl:for-each select="$list[1]">
						<xsl:value-of select="count(.//test)"/>
					</xsl:for-each>
				</xsl:variable>
				<xsl:variable name="rest">
					<xsl:call-template name="MaxTests">
						<xsl:with-param name="list" select="$list[position()!=1]"/>
					</xsl:call-template>
				</xsl:variable>
				<xsl:choose>
					<xsl:when test="normalize-space(translate($first,',','  ')) &gt; normalize-space(translate($rest,',',' ')) ">
						<xsl:value-of select="normalize-space(translate($first,',',' '))"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$rest"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>0</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="MatchIndices">
		<xsl:param name="totalCount"/>
		<xsl:param name="tokenizedIndex"/>
		<xsl:choose>
			<xsl:when test="contains($tokenizedIndex, ',')">
				<xsl:if test="substring-before($tokenizedIndex, ',') &gt; $totalCount">,<xsl:value-of select="substring-before($tokenizedIndex, ',')"/></xsl:if>
				<xsl:call-template name="MatchIndices">
					<xsl:with-param name="totalCount" select="$totalCount"/>
					<xsl:with-param name="tokenizedIndex" select="substring-after($tokenizedIndex, ',')"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="$tokenizedIndex &gt; $totalCount">,<xsl:value-of select="$tokenizedIndex"/></xsl:if>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="TokenizedMatch">
		<xsl:param name="totalCount"/>
		<xsl:param name="tokenizedIndex"/>
		<xsl:choose>
			<xsl:when test="contains($tokenizedIndex, ',')">
				<xsl:if test="substring-before($tokenizedIndex, ',') &lt;= $totalCount">,<xsl:value-of select="substring-before($tokenizedIndex, ',')"/></xsl:if>
				<xsl:call-template name="TokenizedMatch">
					<xsl:with-param name="totalCount" select="$totalCount"/>
					<xsl:with-param name="tokenizedIndex" select="substring-after($tokenizedIndex, ',')"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="$tokenizedIndex &lt;= $totalCount">,<xsl:value-of select="$tokenizedIndex"/></xsl:if>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="SpecifyPartialDisplay">
		<xsl:param name="totalCount"/>
		<xsl:param name="tokenizedIndex"/>
		<xsl:choose>
			<xsl:when test="contains($tokenizedIndex, ',')">
				<xsl:if test="substring-before($tokenizedIndex, ',') &lt;= $totalCount">yes,</xsl:if>
				<xsl:call-template name="SpecifyPartialDisplay">
					<xsl:with-param name="totalCount" select="$totalCount"/>
					<xsl:with-param name="tokenizedIndex" select="substring-after($tokenizedIndex, ',')"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="$tokenizedIndex &lt;= $totalCount">yes,</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="device" mode="xml">
		<xsl:variable name="index"><xsl:number level="any"/></xsl:variable>
		<xsl:choose>
			<xsl:when test="$device-index !=''">
				<xsl:if test="contains($modDevice-index, concat(',', $index, ','))">
					<xsl:copy>
						<xsl:attribute name="index"><xsl:value-of select="$index"/></xsl:attribute>
						<xsl:apply-templates select="@* | node()" mode="xml"/>
					</xsl:copy>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy>
					<xsl:attribute name="index"><xsl:value-of select="$index"/></xsl:attribute>
					<xsl:apply-templates select="@* | node()" mode="xml"/>
				</xsl:copy>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="test" mode="xml">
		<xsl:variable name="index"><xsl:number level="multiple"/></xsl:variable>
		<xsl:choose>
			<xsl:when test="$test-index !=''">
				<xsl:if test="contains($modTest-index, concat(',', $index, ','))">
					<xsl:copy>
						<xsl:attribute name="index"><xsl:value-of select="$index"/></xsl:attribute>
						<xsl:apply-templates select="@* | node()" mode="xml"/>
					</xsl:copy>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy>
					<xsl:attribute name="index"><xsl:value-of select="$index"/></xsl:attribute>
					<xsl:apply-templates select="@* | node()" mode="xml"/>
				</xsl:copy>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="@* | node()" mode="xml">
		<xsl:if test="(name() != '_Key') and (name() !='sequenceKey')">
		<xsl:copy>
			<xsl:copy-of select="@*"/>
			<xsl:apply-templates select="node()" mode="xml"/>
		</xsl:copy>
		</xsl:if>
	</xsl:template>

	<xsl:template name="NewLine">
		<xsl:text>
</xsl:text>
	</xsl:template>
	<xsl:template match="*"></xsl:template>
</xsl:stylesheet>
