<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="xml" indent="yes" omit-xml-declaration="yes"/>
	<xsl:strip-space elements="*"/>
	<!-- Deciding Params-->
	<xsl:param name="outfmt">12</xsl:param>
	<xsl:param name="deviceclass"/>
	<xsl:param name="test-index"></xsl:param>
	<!-- Deciding Params-->
	<xsl:variable name="deviceClassNotFound">The device class requested is not present/enumerated.</xsl:variable>
	<xsl:variable name="testsNotFound">No matching test infomation available for the requested device class.</xsl:variable>
	<xsl:variable name="testIndexNotFound">No matching test was found while querying diagnostic test(s).</xsl:variable>
	<xsl:variable name="someTestIndexNotFound">No matching test was found for the test index</xsl:variable>
	<xsl:variable name="testCount" select="count(/tree//device//test)"/>
	<xsl:variable name="modTest-index" select="concat(',', $test-index, ',')"/>

	<xsl:template match="tree">
		<xsl:variable name="deviceCount" select="count(.//device)"/>
		<xsl:choose>
			<xsl:when test="$deviceCount &gt; 0">
				<xsl:variable name="maxIndTests">
					<xsl:call-template name="MaxTests">
						<xsl:with-param name="list" select=".//device"/>
					</xsl:call-template>
				</xsl:variable>
				<xsl:choose>
                        		<xsl:when test="$testCount &gt; 0">
						<!--
						<xsl:call-template name="NewLine"/>
						<xsl:element name="tree">
							<xsl:apply-templates select="device" mode="xml"/>
						</xsl:element>
						<xsl:call-template name="NewLine"/>
						-->
						<xsl:choose>
						<xsl:when test="$test-index !=''">
							<xsl:choose>
								<xsl:when test="contains($test-index, ',')">
									<xsl:variable name="NoMatchedIndex">
										<xsl:call-template name="MatchIndices">
											<xsl:with-param name="totalCount" select="$maxIndTests"/>
											<xsl:with-param name="tokenizedIndex" select="$test-index"/>
										</xsl:call-template>
									</xsl:variable>
									<xsl:variable name="partialDisplayed">
										<xsl:call-template name="SpecifyPartialDisplay">
											<xsl:with-param name="totalCount" select="$maxIndTests"/>
											<xsl:with-param name="tokenizedIndex" select="$test-index"/>
										</xsl:call-template>
									</xsl:variable>
									<xsl:choose>
									<xsl:when test="$NoMatchedIndex !=''">
										<xsl:choose>
											<xsl:when test="contains($partialDisplayed, 'yes')">
												<xsl:call-template name="NewLine"/>
													<xsl:element name="tree">
														<xsl:apply-templates select="device" mode="xml"/>
													</xsl:element>
												<xsl:call-template name="NewLine"/>
												<xsl:call-template name="NewLine"/>
												<xsl:value-of select="$someTestIndexNotFound"/> - <xsl:value-of select="substring-after($NoMatchedIndex, ',')"/>
												<xsl:call-template name="NewLine"/>
											</xsl:when>
											<xsl:otherwise>
												<xsl:call-template name="NewLine"/>
												<xsl:value-of select="$testIndexNotFound"/>
												<xsl:call-template name="NewLine"/>
											</xsl:otherwise>
										</xsl:choose>
									</xsl:when>
									<xsl:otherwise>
										<xsl:call-template name="NewLine"/>
											<xsl:element name="tree">
												<xsl:apply-templates select="device" mode="xml"/>
											</xsl:element>
										<xsl:call-template name="NewLine"/>
									</xsl:otherwise>
									</xsl:choose>
								</xsl:when>
								<xsl:otherwise>
									<xsl:choose>
									<xsl:when test="$test-index &gt; $maxIndTests">
										<xsl:call-template name="NewLine"/>
										<xsl:value-of select="$testIndexNotFound"/>
										<xsl:call-template name="NewLine"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:call-template name="NewLine"/>
											<xsl:element name="tree">
												<xsl:apply-templates select="device" mode="xml"/>
											</xsl:element>
										<xsl:call-template name="NewLine"/>
									</xsl:otherwise>
									</xsl:choose>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:when>
						<xsl:otherwise>
							<xsl:call-template name="NewLine"/>
								<xsl:element name="tree">
									<xsl:apply-templates select="device" mode="xml"/>
								</xsl:element>
							<xsl:call-template name="NewLine"/>
						</xsl:otherwise>
						</xsl:choose>
                        		</xsl:when>
                        		<xsl:otherwise> 
						<xsl:call-template name="NewLine"/>
						<xsl:value-of select="$testsNotFound"/>
						<xsl:call-template name="NewLine"/>
                        		</xsl:otherwise> 
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="NewLine"/>
				<xsl:value-of select="$deviceClassNotFound"/>
				<xsl:call-template name="NewLine"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="MatchIndices">
		<xsl:param name="totalCount"/>
		<xsl:param name="tokenizedIndex"/>
		<xsl:choose>
			<xsl:when test="contains($tokenizedIndex, ',')">
				<xsl:if test="substring-before($tokenizedIndex, ',') &gt; $totalCount">,<xsl:value-of select="substring-before($tokenizedIndex, ',')"/></xsl:if>
				<xsl:call-template name="MatchIndices">
					<xsl:with-param name="totalCount" select="$totalCount"/>
					<xsl:with-param name="tokenizedIndex" select="substring-after($tokenizedIndex, ',')"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="$tokenizedIndex &gt; $totalCount">,<xsl:value-of select="$tokenizedIndex"/></xsl:if>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="SpecifyPartialDisplay">
		<xsl:param name="totalCount"/>
		<xsl:param name="tokenizedIndex"/>
		<xsl:choose>
			<xsl:when test="contains($tokenizedIndex, ',')">
				<xsl:if test="substring-before($tokenizedIndex, ',') &lt;= $totalCount">yes,</xsl:if>
				<xsl:call-template name="SpecifyPartialDisplay">
					<xsl:with-param name="totalCount" select="$totalCount"/>
					<xsl:with-param name="tokenizedIndex" select="substring-after($tokenizedIndex, ',')"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="$tokenizedIndex &lt;= $totalCount">yes,</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="MaxTests">
		<xsl:param name="list"/>
		<xsl:choose>
			<xsl:when test="$list">
				<xsl:variable name="first">
					<xsl:for-each select="$list[1]">
						<xsl:value-of select="count(.//test)"/>
					</xsl:for-each>
				</xsl:variable>
				<xsl:variable name="rest">
					<xsl:call-template name="MaxTests">
						<xsl:with-param name="list" select="$list[position()!=1]"/>
					</xsl:call-template>
				</xsl:variable>
				<xsl:choose>
					<xsl:when test="normalize-space(translate($first,',','  ')) &gt; normalize-space(translate($rest,',',' ')) ">
						<xsl:value-of select="normalize-space(translate($first,',',' '))"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$rest"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>0</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

<!--
	<xsl:template match="tree">
		<xsl:variable name="deviceCount" select="count(.//device)"/>
		<xsl:choose>
			<xsl:when test="$deviceCount &gt; 0">
				<xsl:choose>
                        	<xsl:when test="$testCount &gt; 0">
						<xsl:call-template name="NewLine"/>
						<xsl:element name="tree">
							<xsl:apply-templates select="device" mode="xml"/>
						</xsl:element>
                        	</xsl:when>
                        	<xsl:otherwise> 
						<xsl:call-template name="NewLine"/>
						<xsl:value-of select="$testsNotFound"/>
                        	</xsl:otherwise> 
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="NewLine"/>
				<xsl:value-of select="$deviceClassNotFound"/>
				<xsl:call-template name="NewLine"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
-->
	<xsl:template match="device" mode="xml">
		<xsl:apply-templates select="test[not(testMnemonic=preceding::test/testMnemonic)]" mode="xml"/>
	</xsl:template>

	<xsl:template match="test" mode="xml">
		<xsl:variable name="index"><xsl:number level="multiple"/></xsl:variable>
		<xsl:choose>
			<xsl:when test="$test-index !=''">
				<xsl:if test="contains($modTest-index, concat(',', $index, ','))">
					<xsl:copy>
						<xsl:attribute name="index"><xsl:value-of select="$index"/></xsl:attribute>
						<xsl:apply-templates select="@* | node()" mode="xml"/>
					</xsl:copy>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy>
					<xsl:attribute name="index"><xsl:value-of select="$index"/></xsl:attribute>
					<xsl:apply-templates select="@* | node()" mode="xml"/>
				</xsl:copy>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="@* | node()" mode="xml">
		<xsl:if test="(name() != '_Key') and (name() !='sequenceKey')">
		<xsl:copy>
			<xsl:copy-of select="@*"/>
			<xsl:apply-templates select="node()" mode="xml"/>
		</xsl:copy>
		</xsl:if>
	</xsl:template>

	<xsl:template name="NewLine">
		<xsl:text>
</xsl:text>
	</xsl:template>
	<xsl:template match="*"></xsl:template>
</xsl:stylesheet>
