#!/bin/sh
###############################################################################
#
#          Dell Inc. PROPRIETARY INFORMATION
# This software is supplied under the terms of a license agreement or
# nondisclosure agreement with Dell Inc. and may not
# be copied or disclosed except in accordance with the terms of that
# agreement.
#
# Copyright (c) 2000-2006 Dell Inc. All Rights Reserved.
#
# Module Name:
#
#   startDiags.sh
#
#
# Abstract/Purpose:
#
#   This script will start Dell(R) PowerEdge(R) Diagnostics in GUI mode.
#
# Environment:
#
#   Linux
#
###############################################################################

msgDISPLAY="\tPlease run the application from your X console"
msgXHOST="\tAccess control is not enabled for X server. Try configuring the access control with 'xhost' command"

ARG0=$0
[ -z `dirname $ARG0 | cut -d/ -f1` ] || ARG0=$PWD/$ARG0
TOPDIR=`dirname $ARG0`/oldiags
BINDIR=$TOPDIR/bin
LIBDIR=$TOPDIR/lib
LOGDIR=$TOPDIR/log

[ -f $LOGDIR ] && rm -f $LOGDIR
[ -e $LOGDIR ] || mkdir $LOGDIR

export LD_LIBRARY_PATH=$BINDIR:$BINDIR/gtk
jars=`echo $LIBDIR/*.jar $LIBDIR/gtk/*.jar | sed 's/ /:/g'`
jre=gij

cd $TOPDIR
for i in "$TOPDIR/*.sh"; do
    $i >/dev/null 2>&1
done

cd $BINDIR
if [ -z $DISPLAY ]; then
    msgError=$msgDISPLAY
else
    if [ -f /etc/redhat-release ]; then
        redhatRelease=`cat /etc/redhat-release`
    
        #check for Em64T; T3Lite GUI supports U4 onwards
        if [ "`echo ${redhatRelease} | grep "Taroon"`" != "" ] && [ "${HOSTTYPE}" == "x86_64" ]; then
            taroonStr=`echo ${redhatRelease} | cut -d'(' -f2 | cut -d')' -f1`
            if [ `echo ${taroonStr} | wc -w` -eq "3" ]; then     # not an update release
                if [ `echo ${taroonStr} | cut -d' ' -f3` -lt "4" ]; then
                    errorMsg="PowerEdge Diagnostics GUI supports Red Hat Enterprise Linux AS, ES, WS (version 3) Update 4 onwards for Intel EM64T."
                fi
            else
                errorMsg="PowerEdge Diagnostics GUI supports Red Hat Enterprise Linux AS, ES, WS (version 3) Update 4 onwards for Intel EM64T."
            fi
        
            if [ "${errorMsg}" != "" ]; then
                echo -e ${errorMsg}
	        exit 1
            fi
        fi

        #check for Compatibility Arch Support packages [pango, gtk and redhat-artwork]
        if [ "${HOSTTYPE}" == "x86_64" ]; then
            compatArchRpms="redhat-artwork pango gtk2"
	    casp1fileRHEL3="/usr/lib/gtk-2.0/2.2.0/engines/libbluecurve.so"
	    casp2fileRHEL3="/usr/lib/libpango-1.0.so.0"
	    casp3fileRHEL3="/usr/lib/libgdk-x11-2.0.so.0"
	    casp1fileRHEL4="/usr/lib/gtk-2.0/2.4.0/engines/libbluecurve.so"
	    casp2fileRHEL4="/usr/lib/libpango-1.0.so.0"
	    casp3fileRHEL4="/usr/lib/libgdk-x11-2.0.so.0"

            guiDepMesg="\nCompatibility Arch Support package(s) [gtk, pango, and redhat-artwork] is not installed on this system. For details on installing the package(s) please refer to the README file."

    	    if [ "`echo ${redhatRelease} | grep "Taroon"`" != "" ]; then
	        (rpm -q ${compatArchRpms} && test -f ${casp1fileRHEL3} && test -f ${casp2fileRHEL3} && test -f ${casp3fileRHEL3}) > /dev/null 2>&1
	        if [ $? -ne 0 ]; then
	            echo -e ${guiDepMesg}
	            exit 1
	        fi
            elif [ "`echo ${redhatRelease} | grep "Nahant"`" != "" ]; then
	        (rpm -q ${compatArchRpms} && test -f ${casp1fileRHEL4} && test -f ${casp2fileRHEL4} && test -f ${casp3fileRHEL4}) > /dev/null 2>&1
	        if [ $? -ne 0 ]; then
	            echo -e ${guiDepMesg}
	            exit 1
	        fi
            fi
        fi
    fi

    xhost > /dev/null 2>&1
    if [ $? -eq 0 ]; then
        export PATH=/sbin:$PATH
	if [ "`rpm -qa | grep "scim-32"`" != "" ]; then
		export GTK_IM_MODULE=xim
	fi
        exec $BINDIR/StartDiags >/dev/null 2>&1
        msgError=$msgArchive
    else
        msgError="$msgXHOST"
    fi
fi

if [ "$msgError" != "" ]; then
  echo -e "Dell PowerEdge Diagnostics cannot start.\n" $msgError
  exit -1
fi
