#!/bin/sh
###############################################################################
#
#          Dell Inc. PROPRIETARY INFORMATION
#
# This software is supplied under the terms of a license agreement or
# nondisclosure agreement with Dell Inc. and may not
# be copied or disclosed except in accordance with the terms of that
# agreement.
#
# Copyright (c) 2000-2006 Dell Inc. All Rights Reserved.
#
# Module Name:
#
#   uninstall.sh
#
#
# Abstract/Purpose:
#
#   This script uninstalls all the rpm packages installed by Dell(R) 
#   PowerEdge(R) Diagnostics from the system.
#
#
# Environment:
#
#   Linux
#
###############################################################################

omilPackage=/var/spool/repackage/srvadmin-omilcore-*.rpm

echo_success() {
    echo -en "\t" [ 
    echo -en "\\033[1;32m" OK 
    echo -en "\\033[0;39m" ]
    echo
}

echo_fail() {
    echo -en "\t" [ 
    echo -en "\\033[1;31m" FAILED 
    echo -en "\\033[0;39m" ]
    echo
}

if [ ${UID} != 0 ]; then
   echo This utility requires root privileges
   echo
   exit 1
fi

if test -f /var/lock/.spsetup; then
   echo DUP is running. Please retry later.
else
   if which omreport >/dev/null 2>&1; then
      echo OMSA is installed - ignoring dependencies
   else
      if rpm -q --whatprovides srvadmin-hapi >/dev/null 2>&1; then
         hapiDeps=`rpm -q --whatrequires srvadmin-hapi|grep -v srvadmin-hapi`
         if test -z "`echo $hapiDeps | grep -v -i pediags`" ; then
            echo -ne "Uninstalling srvadmin-hapi:"
            test -f /var/lock/.spsetup || rpm -ev srvadmin-hapi --nodeps
   	    if test $? -eq 0; then
      	       echo_success
            else
               echo_fail
            fi
         else
            echo Preserving srvadmin-hapi \(required\).
         fi
      else
         echo Skipping srvadmin-hapi \(not installed\).
      fi
      if rpm -q --whatprovides srvadmin-ipmi >/dev/null 2>&1; then
	 ipmiDeps=`rpm -q --whatrequires srvadmin-ipmi |grep -v srvadmin-ipmi`
         if test -z "`echo $ipmiDeps | grep -v -i pediags`"; then
            echo -ne "Uninstalling srvadmin-ipmi:"
            test -f /var/lock/.spsetup || rpm -ev srvadmin-ipmi --nodeps
   	    if test $? -eq 0; then
      	       echo_success
            else
               echo_fail
            fi
         else
            echo Preserving srvadmin-ipmi \(required\).
         fi
      else
         echo Skipping srvadmin-ipmi \(not installed\).
      fi
      if rpm -q --whatprovides srvadmin-omilcore >/dev/null 2>&1; then
         if rpm -q --whatrequires srvadmin-omilcore >/dev/null 2>&1; then
            if test -f $omilPackage; then
               echo Restoring repackaged srvadmin-omilcore.
               omilFlags="--oldpackage --nosignature --nodigest"
               test -f /var/lock/.spsetup \
               || OMIIGNORESYSID=true rpm -Uhv $omilPackage $omilFlags \
               && rm -f $omilPackage
            else
               echo Preserving srvadmin-omilcore \(required\).
            fi
         else
            echo -ne "Uninstalling srvadmin-omilcore:"
            test -f /var/lock/.spsetup || rpm -ev srvadmin-omilcore
   	    if test $? -eq 0; then
      	       echo_success
            else
               echo_fail
            fi
            test -f $omilPackage && rm -f $omilPackage
         fi
      else
         echo Skipping srvadmin-omilcore \(not installed\).
      fi
   fi
   if rpm -q --whatprovides dell-pediags >/dev/null 2>&1; then
      echo -ne "Uninstalling dell-pediags:"
      test -f /var/lock/.spsetup || rpm -ev dell-pediags
      if test $? -eq 0; then
         echo_success
      else
         echo_fail
      fi
   else
      echo Skipping dell-pediags \(not installed\).
  fi
fi

